function [llf] = likelihood(x,y,X,n,k,w,p,inc,tyear,ind,rich);

% x is the updated value for the coefficients
% note: error st.devs are the squared of the estimated parameter x(end) and x(end-1) to ensure >0
% k: number of controls including constant

bc=x(1:k);  %delta vector
bp=x(k+1);  %alpha
by=x(k+2);  %gamma

sn=x(end-1)^2;  %sigma_eta
s0=x(end)^2;  %sigma_epsilon
sv=sqrt((s0^2)+(sn^2));  %sigma(v)
corr=sn/sv;  %rho

display(x);

wstar1=X*bc+bp*(p(:,1))+by*inc(:,1); %wstar(k) is w0(k) in Proposition 1
wstar2=X*bc+bp*(p(:,2))+by*inc(:,2);
wstar3=X*bc+bp*(p(:,3))+by*inc(:,3);
wstar4=X*bc+bp*(p(:,4))+by*inc(:,4); 
wstar5=X*bc+bp*(p(:,5))+by*inc(:,5);
wstar6=X*bc+bp*(p(:,6))+by*inc(:,6);
wstar7=X*bc+bp*(p(:,7))+by*inc(:,7);
wstar8=X*bc+bp*(p(:,8))+by*inc(:,8);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%          COMPUTING THRESHOLDS (Proposition 1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% FEASIBILITY AND SEGMENT VS. SEGMENT THRESHOLDS (theta_jk and eta_jk)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

theta11=w(:,1)-wstar1;  %these are theta_ij in Proposition 1
theta12=w(:,1)-wstar2;
theta22=w(:,2)-wstar2;
theta23=w(:,2)-wstar3;
theta33=w(:,3)-wstar3;
theta34=w(:,3)-wstar4;
theta44=w(:,4)-wstar4;
theta45=w(:,4)-wstar5;
theta55=w(:,5)-wstar5;
theta56=w(:,5)-wstar6;
theta66=w(:,6)-wstar6;
theta67=w(:,6)-wstar7;
theta77=w(:,7)-wstar7;
theta78=w(:,7)-wstar8;

% replacing theta_77 with a large number when segment 7 is the last one (in this case theta78 will not be used), same for theta_66
for i=1:n
    if tyear(i)<=3
        theta77(i,1)=500;
    end
    if rich(i)==0 && (tyear(i)==7 || tyear(i)==8)
           theta77(i,1)=500;
    end 
    if rich(i)==0 && (tyear(i)==5 || tyear(i)==6)
        theta66(i)=500;
    end
end

%computing eta_jk, using V_j and V_k, which are computed by the indirect function:
eta23=etakl(indirect(p(:,2),inc(:,2),by,bp,X,bc),p(:,2),indirect(p(:,3),inc(:,3),by,bp,X,bc),p(:,3),by); % note that eta13, eta14 etc. not needed b/c will always have theta11 as lower bound when computing the bounds
eta24=etakl(indirect(p(:,2),inc(:,2),by,bp,X,bc),p(:,2),indirect(p(:,4),inc(:,4),by,bp,X,bc),p(:,4),by);
eta25=etakl(indirect(p(:,2),inc(:,2),by,bp,X,bc),p(:,2),indirect(p(:,5),inc(:,5),by,bp,X,bc),p(:,5),by);
eta26=etakl(indirect(p(:,2),inc(:,2),by,bp,X,bc),p(:,2),indirect(p(:,6),inc(:,6),by,bp,X,bc),p(:,6),by);
eta27=etakl(indirect(p(:,2),inc(:,2),by,bp,X,bc),p(:,2),indirect(p(:,7),inc(:,7),by,bp,X,bc),p(:,7),by);

eta34=etakl(indirect(p(:,3),inc(:,3),by,bp,X,bc),p(:,3),indirect(p(:,4),inc(:,4),by,bp,X,bc),p(:,4),by);
eta35=etakl(indirect(p(:,3),inc(:,3),by,bp,X,bc),p(:,3),indirect(p(:,5),inc(:,5),by,bp,X,bc),p(:,5),by);
eta36=etakl(indirect(p(:,3),inc(:,3),by,bp,X,bc),p(:,3),indirect(p(:,6),inc(:,6),by,bp,X,bc),p(:,6),by);
eta37=etakl(indirect(p(:,3),inc(:,3),by,bp,X,bc),p(:,3),indirect(p(:,7),inc(:,7),by,bp,X,bc),p(:,7),by);

eta45=etakl(indirect(p(:,4),inc(:,4),by,bp,X,bc),p(:,4),indirect(p(:,5),inc(:,5),by,bp,X,bc),p(:,5),by);
eta46=etakl(indirect(p(:,4),inc(:,4),by,bp,X,bc),p(:,4),indirect(p(:,6),inc(:,6),by,bp,X,bc),p(:,6),by);
eta47=etakl(indirect(p(:,4),inc(:,4),by,bp,X,bc),p(:,4),indirect(p(:,7),inc(:,7),by,bp,X,bc),p(:,7),by);
eta48=etakl(indirect(p(:,4),inc(:,4),by,bp,X,bc),p(:,4),indirect(p(:,8),inc(:,8),by,bp,X,bc),p(:,8),by);

eta56=etakl(indirect(p(:,5),inc(:,5),by,bp,X,bc),p(:,5),indirect(p(:,6),inc(:,6),by,bp,X,bc),p(:,6),by);
eta57=etakl(indirect(p(:,5),inc(:,5),by,bp,X,bc),p(:,5),indirect(p(:,7),inc(:,7),by,bp,X,bc),p(:,7),by);
eta58=etakl(indirect(p(:,5),inc(:,5),by,bp,X,bc),p(:,5),indirect(p(:,8),inc(:,8),by,bp,X,bc),p(:,8),by);

eta67=etakl(indirect(p(:,6),inc(:,6),by,bp,X,bc),p(:,6),indirect(p(:,7),inc(:,7),by,bp,X,bc),p(:,7),by);


% SEGMENT VS. KINK THRESHOLDS (uL_jk and uH_jk)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ua13 is uL_13 and uf13 is uH_13, etc. These are computed by function "difference"
% Note that these only need to be computed if U=V has two roots, which happens iff for eta* where U'(eta*)=V'(eta*) we have V(eta*)<U(eta*)
% We check this using the function condition = V(eta*)-U(eta*) < 0

ua13=zeros(n,1);
ua14=zeros(n,1);
ua15=zeros(n,1);
ua16=zeros(n,1);
ua17=zeros(n,1);
uf13=zeros(n,1);
uf14=zeros(n,1);
uf15=zeros(n,1);
uf16=zeros(n,1);
uf17=zeros(n,1);

ua72=zeros(n,1);
ua73=zeros(n,1);
ua74=zeros(n,1);
ua75=zeros(n,1);
ua76=zeros(n,1);
uf72=zeros(n,1);
uf73=zeros(n,1);
uf74=zeros(n,1);
uf75=zeros(n,1);
uf76=zeros(n,1);

ua62=zeros(n,1);
ua63=zeros(n,1);
ua64=zeros(n,1);
ua65=zeros(n,1);
uf62=zeros(n,1);
uf63=zeros(n,1);
uf64=zeros(n,1);
uf65=zeros(n,1);

ua36=zeros(n,1);
ua37=zeros(n,1);
ua46=zeros(n,1);
ua47=zeros(n,1);
uf36=zeros(n,1);
uf37=zeros(n,1);
uf46=zeros(n,1);
uf47=zeros(n,1);


%YEARS 1-6

% Kink 1 vs segments

for i=1:n
    if (tyear(i,1)==1 || tyear(i,1)==2 || tyear(i,1)==3|| tyear(i,1)==4|| tyear(i,1)==5|| tyear(i,1)==6) && rich(i,1)==1
        %if convexity violated at kink 1, set ua = uf for all comparisions with that kink so it can never be the optimum
        if by*w(i,1)+bp<0            
            if condition(p(i,3),inc(i,3),p(i,1),w(i,1),inc(i,1),by,bp,bc,X(i,:),ccvu(p(i,3),w(i,1),p(i,1),inc(i,1),by,bp,X(i,:),bc))<0
                ua13(i,1)=fsolve(@(xx) difference(p(i,1),inc(i,1),w(i,1),p(i,3),inc(i,3),by,bp,X(i,:),bc,xx),[-500],options);
                uf13(i,1)=fsolve(@(xx) difference(p(i,1),inc(i,1),w(i,1),p(i,3),inc(i,3),by,bp,X(i,:),bc,xx),[500],options);
            end
            if condition(p(i,4),inc(i,4),p(i,1),w(i,1),inc(i,1),by,bp,bc,X(i,:),ccvu(p(i,4),w(i,1),p(i,1),inc(i,1),by,bp,X(i,:),bc))<0
                ua14(i,1)=fsolve(@(xx) difference(p(i,1),inc(i,1),w(i,1),p(i,4),inc(i,4),by,bp,X(i,:),bc,xx),[-500],options);
                uf14(i,1)=fsolve(@(xx) difference(p(i,1),inc(i,1),w(i,1),p(i,4),inc(i,4),by,bp,X(i,:),bc,xx),[500],options);
            end
            if condition(p(i,5),inc(i,5),p(i,1),w(i,1),inc(i,1),by,bp,bc,X(i,:),ccvu(p(i,5),w(i,1),p(i,1),inc(i,1),by,bp,X(i,:),bc))<0
                ua15(i,1)=fsolve(@(xx) difference(p(i,1),inc(i,1),w(i,1),p(i,5),inc(i,5),by,bp,X(i,:),bc,xx),[-500],options);
                uf15(i,1)=fsolve(@(xx) difference(p(i,1),inc(i,1),w(i,1),p(i,5),inc(i,5),by,bp,X(i,:),bc,xx),[500],options);                
            end
            if condition(p(i,6),inc(i,6),p(i,1),w(i,1),inc(i,1),by,bp,bc,X(i,:),ccvu(p(i,6),w(i,1),p(i,1),inc(i,1),by,bp,X(i,:),bc))<0
                ua16(i,1)=fsolve(@(xx) difference(p(i,1),inc(i,1),w(i,1),p(i,6),inc(i,6),by,bp,X(i,:),bc,xx),[-500],options);
                uf16(i,1)=fsolve(@(xx) difference(p(i,1),inc(i,1),w(i,1),p(i,6),inc(i,6),by,bp,X(i,:),bc,xx),[500],options);               
            end
            if condition(p(i,7),inc(i,7),p(i,1),w(i,1),inc(i,1),by,bp,bc,X(i,:),ccvu(p(i,7),w(i,1),p(i,1),inc(i,1),by,bp,X(i,:),bc))<0
                ua17(i,1)=fsolve(@(xx) difference(p(i,1),inc(i,1),w(i,1),p(i,7),inc(i,7),by,bp,X(i,:),bc,xx),[-500],options);
                uf17(i,1)=fsolve(@(xx) difference(p(i,1),inc(i,1),w(i,1),p(i,7),inc(i,7),by,bp,X(i,:),bc,xx),[500],options);                
            end
        end
    end
end

% Kink 7 vs segments

for i=1:n
    if (tyear(i,1)==4|| tyear(i,1)==5|| tyear(i,1)==6) && rich(i,1)==1
        if by*w(i,7)+bp<0
            if condition(p(i,2),inc(i,2),p(i,7),w(i,7),inc(i,7),by,bp,bc,X(i,:),ccvu(p(i,2),w(i,7),p(i,7),inc(i,7),by,bp,X(i,:),bc))<0
                ua72(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,2),inc(i,2),by,bp,X(i,:),bc,xx),[-500],options);
                uf72(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,2),inc(i,2),by,bp,X(i,:),bc,xx),[500],options); 
            end
            if condition(p(i,3),inc(i,3),p(i,7),w(i,7),inc(i,7),by,bp,bc,X(i,:),ccvu(p(i,3),w(i,7),p(i,7),inc(i,7),by,bp,X(i,:),bc))<0
                ua73(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,3),inc(i,3),by,bp,X(i,:),bc,xx),[-500],options);
                uf73(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,3),inc(i,3),by,bp,X(i,:),bc,xx),[500],options);              
            end
            if (tyear(i,1)==4|| tyear(i,1)==5) && rich(i,1)==1
                if condition(p(i,4),inc(i,4),p(i,7),w(i,7),inc(i,7),by,bp,bc,X(i,:),ccvu(p(i,4),w(i,7),p(i,7),inc(i,7),by,bp,X(i,:),bc))<0
                    ua74(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,4),inc(i,4),by,bp,X(i,:),bc,xx),[-500],options);
                    uf74(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,4),inc(i,4),by,bp,X(i,:),bc,xx),[500],options);                   
                end
                if condition(p(i,5),inc(i,5),p(i,7),w(i,7),inc(i,7),by,bp,bc,X(i,:),ccvu(p(i,5),w(i,7),p(i,7),inc(i,7),by,bp,X(i,:),bc))<0
                    ua75(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,5),inc(i,5),by,bp,X(i,:),bc,xx),[-500],options);
                    uf75(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,5),inc(i,5),by,bp,X(i,:),bc,xx),[500],options);                    
                end
            end
            if tyear(i,1)==4 && rich(i,1)==1
                if condition(p(i,6),inc(i,6),p(i,7),w(i,7),inc(i,7),by,bp,bc,X(i,:),ccvu(p(i,6),w(i,7),p(i,7),inc(i,7),by,bp,X(i,:),bc))<0
                    ua76(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,6),inc(i,6),by,bp,X(i,:),bc,xx),[-500],options);
                    uf76(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,6),inc(i,6),by,bp,X(i,:),bc,xx),[500],options);                  
                end
            end
            if (tyear(i,1)==5|| tyear(i,1)==6) && rich(i,1)==1
                ua76(i,1)=-500;
                uf76(i,1)=500;
            end
            if tyear(i,1)==6 && rich(i,1)==1
                ua74(i,1)=-500;
                uf74(i,1)=500;
                ua75(i,1)=-500;
                uf75(i,1)=500;
            end
        end
    end
end

% Kink 6 vs segments

for i=1:n
    if (tyear(i,1)==5|| tyear(i,1)==6) && rich(i,1)==1
        if by*w(i,6)+bp<0
            if condition(p(i,2),inc(i,2),p(i,6),w(i,6),inc(i,6),by,bp,bc,X(i,:),ccvu(p(i,2),w(i,6),p(i,6),inc(i,6),by,bp,X(i,:),bc))<0
                ua62(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,2),inc(i,2),by,bp,X(i,:),bc,xx),[-500],options);
                uf62(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,2),inc(i,2),by,bp,X(i,:),bc,xx),[500],options);
            end
            if condition(p(i,3),inc(i,3),p(i,6),w(i,6),inc(i,6),by,bp,bc,X(i,:),ccvu(p(i,3),w(i,6),p(i,6),inc(i,6),by,bp,X(i,:),bc))<0
                ua63(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,3),inc(i,3),by,bp,X(i,:),bc,xx),[-500],options);
                uf63(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,3),inc(i,3),by,bp,X(i,:),bc,xx),[500],options);
            end
            if condition(p(i,4),inc(i,4),p(i,6),w(i,6),inc(i,6),by,bp,bc,X(i,:),ccvu(p(i,4),w(i,6),p(i,6),inc(i,6),by,bp,X(i,:),bc))<0
                ua64(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,4),inc(i,4),by,bp,X(i,:),bc,xx),[-500],options);
                uf64(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,4),inc(i,4),by,bp,X(i,:),bc,xx),[500],options);
            end
            if condition(p(i,5),inc(i,5),p(i,6),w(i,6),inc(i,6),by,bp,bc,X(i,:),ccvu(p(i,5),w(i,6),p(i,6),inc(i,6),by,bp,X(i,:),bc))<0
                ua65(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,5),inc(i,5),by,bp,X(i,:),bc,xx),[-500],options);
                uf65(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,5),inc(i,5),by,bp,X(i,:),bc,xx),[500],options);
            end
        end
    end
end
        
% YEAR 7-8

for i=1:n
    if (tyear(i,1)==7 ||tyear(i,1)==8) && rich(i,1)==1
        if by*w(i,3)+bp<0
            if condition(p(i,6),inc(i,6),p(i,3),w(i,3),inc(i,3),by,bp,bc,X(i,:),ccvu(p(i,6),w(i,3),p(i,3),inc(i,3),by,bp,X(i,:),bc))<0
                ua36(i,1)=fsolve(@(xx) difference(p(i,3),inc(i,6),w(i,3),p(i,6),inc(i,6),by,bp,X(i,:),bc,xx),[-500],options);
                uf36(i,1)=fsolve(@(xx) difference(p(i,3),inc(i,6),w(i,3),p(i,6),inc(i,6),by,bp,X(i,:),bc,xx),[500],options);
            end
            if condition(p(i,7),inc(i,7),p(i,3),w(i,3),inc(i,3),by,bp,bc,X(i,:),ccvu(p(i,7),w(i,3),p(i,3),inc(i,3),by,bp,X(i,:),bc))<0
                ua37(i,1)=fsolve(@(xx) difference(p(i,3),inc(i,3),w(i,3),p(i,7),inc(i,7),by,bp,X(i,:),bc,xx),[-500],options);
                uf37(i,1)=fsolve(@(xx) difference(p(i,3),inc(i,3),w(i,3),p(i,7),inc(i,7),by,bp,X(i,:),bc,xx),[500],options);
            end
        end
        if by*w(i,4)+bp<0
            if condition(p(i,6),inc(i,6),p(i,4),w(i,4),inc(i,4),by,bp,bc,X(i,:),ccvu(p(i,6),w(i,4),p(i,4),inc(i,4),by,bp,X(i,:),bc))<0
                ua46(i,1)=fsolve(@(xx) difference(p(i,4),inc(i,4),w(i,4),p(i,6),inc(i,6),by,bp,X(i,:),bc,xx),[-500],options);
                uf46(i,1)=fsolve(@(xx) difference(p(i,4),inc(i,4),w(i,4),p(i,6),inc(i,6),by,bp,X(i,:),bc,xx),[500],options);
            end
        end
        if by*w(i,6)+bp<0
            if condition(p(i,4),inc(i,4),p(i,6),w(i,6),inc(i,6),by,bp,bc,X(i,:),ccvu(p(i,4),w(i,6),p(i,6),inc(i,6),by,bp,X(i,:),bc))<0
                ua64(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,4),inc(i,4),by,bp,X(i,:),bc,xx),[-500],options);
                uf64(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,4),inc(i,4),by,bp,X(i,:),bc,xx),[500],options);
            end
        end
        if by*w(i,6)+bp<0
            if condition(p(i,5),inc(i,5),p(i,6),w(i,6),inc(i,6),by,bp,bc,X(i,:),ccvu(p(i,5),w(i,6),p(i,6),inc(i,6),by,bp,X(i,:),bc))<0
                ua65(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,5),inc(i,5),by,bp,X(i,:),bc,xx),[-500],options);
                uf65(i,1)=fsolve(@(xx) difference(p(i,6),inc(i,6),w(i,6),p(i,5),inc(i,5),by,bp,X(i,:),bc,xx),[500],options);
            end
        end
        if by*w(i,7)+bp<0
            if condition(p(i,4),inc(i,4),p(i,7),w(i,7),inc(i,7),by,bp,bc,X(i,:),ccvu(p(i,4),w(i,7),p(i,7),inc(i,7),by,bp,X(i,:),bc))<0
                ua74(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,4),inc(i,4),by,bp,X(i,:),bc,xx),[-500],options);
                uf74(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,4),inc(i,4),by,bp,X(i,:),bc,xx),[500],options);
            end
        end
    end
    
    if (tyear(i,1)==7 && ind(i,1)==0 ||tyear(i,1)==8) && rich(i,1)==1
        if by*w(i,4)+bp<0
            if condition(p(i,7),inc(i,7),p(i,4),w(i,4),inc(i,4),by,bp,bc,X(i,:),ccvu(p(i,7),w(i,4),p(i,4),inc(i,4),by,bp,X(i,:),bc))<0
                ua47(i,1)=fsolve(@(xx) difference(p(i,4),inc(i,4),w(i,4),p(i,7),inc(i,7),by,bp,X(i,:),bc,xx),[-500],options);
                uf47(i,1)=fsolve(@(xx) difference(p(i,4),inc(i,4),w(i,4),p(i,7),inc(i,7),by,bp,X(i,:),bc,xx),[500],options);
            end
        end
        if by*w(i,7)+bp<0
            if condition(p(i,5),inc(i,5),p(i,7),w(i,7),inc(i,7),by,bp,bc,X(i,:),ccvu(p(i,5),w(i,7),p(i,7),inc(i,7),by,bp,X(i,:),bc))<0
                ua75(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,5),inc(i,5),by,bp,X(i,:),bc,xx),[-500],options);
                uf75(i,1)=fsolve(@(xx) difference(p(i,7),inc(i,7),w(i,7),p(i,5),inc(i,5),by,bp,X(i,:),bc,xx),[500],options);
            end
        end
    end
    
    if (tyear(i,1)==7 && ind(i,1)==1) && rich(i,1)==1
        ua75(i,1)=-500;
        uf75(i,1)=500;
    end
end


% KINK VS. KINK THRESHOLDS (uu_ij)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%U1>U7 iff eta<uu_17, etc.
%function uuij computes the uu_17 cutoffs

uu16=uuij(p(:,1),w(:,1),inc(:,1),p(:,6),w(:,6),inc(:,6),by,bp,X,bc);
uu17=uuij(p(:,1),w(:,1),inc(:,1),p(:,7),w(:,7),inc(:,7),by,bp,X,bc);
uu67=uuij(p(:,6),w(:,6),inc(:,6),p(:,7),w(:,7),inc(:,7),by,bp,X,bc);
uu26=uuij(p(:,2),w(:,2),inc(:,2),p(:,6),w(:,6),inc(:,6),by,bp,X,bc);
uu27=uuij(p(:,2),w(:,2),inc(:,2),p(:,7),w(:,7),inc(:,7),by,bp,X,bc);
uu36=uuij(p(:,3),w(:,3),inc(:,3),p(:,6),w(:,6),inc(:,6),by,bp,X,bc);
uu37=uuij(p(:,3),w(:,3),inc(:,3),p(:,7),w(:,7),inc(:,7),by,bp,X,bc);
uu46=uuij(p(:,4),w(:,4),inc(:,4),p(:,6),w(:,6),inc(:,6),by,bp,X,bc);
uu47=uuij(p(:,4),w(:,4),inc(:,4),p(:,7),w(:,7),inc(:,7),by,bp,X,bc);

%if convexity is violated at the larger (but not the smaller) kink, uuij will be complex. In this case, rule out the larger kink:

for i=1:n
uu16r(i,1)=isreal(uu16(i,1));
uu17r(i,1)=isreal(uu17(i,1));
uu67r(i,1)=isreal(uu67(i,1));
uu26r(i,1)=isreal(uu26(i,1));
uu27r(i,1)=isreal(uu27(i,1));
uu36r(i,1)=isreal(uu36(i,1));
uu37r(i,1)=isreal(uu37(i,1));
uu46r(i,1)=isreal(uu46(i,1));
uu47r(i,1)=isreal(uu47(i,1));
end

for i=1:n
    if uu16r(i,1)==0
        uu16(i,1)=500;
    end
end
for i=1:n
    if uu17r(i,1)==0
        uu17(i,1)=500;
    end
end
for i=1:n
    if uu67r(i,1)==0
        uu67(i,1)=500;
    end
end
for i=1:n
    if uu26r(i,1)==0
        uu26(i,1)=500;
    end
end
for i=1:n
    if uu27r(i,1)==0
        uu27(i,1)=500;
    end
end
for i=1:n
    if uu36r(i,1)==0
        uu36(i,1)=500;
    end
end

for i=1:n
    if uu37r(i,1)==0
        uu37(i,1)=500;
    end
end
for i=1:n
    if uu46r(i,1)==0
        uu46(i,1)=500;
    end
end
for i=1:n
    if uu47r(i,1)==0
        uu47(i,1)=500;
    end
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              CREATING THE BOUNDS 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


up1s=zeros(n,1); %upper bound for segment 1
lo1k=zeros(n,1); %lower bound for kink 1
up1k=zeros(n,1);
lo2s=zeros(n,1);
up2s=zeros(n,1);
lo2k=zeros(n,1);
up2k=zeros(n,1);
lo3s=zeros(n,1);
up3s=zeros(n,1);
lo3k=zeros(n,1);
up3k=zeros(n,1);
lo4s=zeros(n,1);
up4s=zeros(n,1);
lo4k=zeros(n,1);
up4k=zeros(n,1);
lo5s=zeros(n,1);
up5s=zeros(n,1);
lo5k=zeros(n,1);
up5k=zeros(n,1);
lo6s=zeros(n,1);
up6s=zeros(n,1);
lo6k=zeros(n,1);
up6k=zeros(n,1);
lo7s=zeros(n,1);
up7s=zeros(n,1);
lo7k=zeros(n,1);
up7k=zeros(n,1);
lo8s=zeros(n,1);

lo1ka=zeros(n,1); %lower bound for kink 1 in alternative interval
up1ka=zeros(n,1);
lo2sa=zeros(n,1);
up2sa=zeros(n,1);
lo2ka=zeros(n,1);
up2ka=zeros(n,1);
lo3sa=zeros(n,1);
up3sa=zeros(n,1);
lo3ka=zeros(n,1);
up3ka=zeros(n,1);
lo4sa=zeros(n,1);
up4sa=zeros(n,1);
lo4ka=zeros(n,1);
up4ka=zeros(n,1);
lo5sa=zeros(n,1);
up5sa=zeros(n,1);
lo6sa=zeros(n,1);
up6sa=zeros(n,1);
lo6ka=zeros(n,1);
up6ka=zeros(n,1);
lo7sa=zeros(n,1);
up7sa=zeros(n,1);
lo7ka=zeros(n,1);
up7ka=zeros(n,1);
lo8s=zeros(n,1);

big=500; %a big number

%1 segment
up1s=max(-big,theta11);


for i=1:n

    %YEARS 1-3
    %%%%%%%%%%
    if (tyear(i,1)==1 || tyear(i,1)==2 || tyear(i,1)==3) && rich(i,1)==1
        
        %1 kink point
        %function kinksegment(a,b,c,d,e,f,g,h) gives the lower and upper bounds for eta s.t a<eta<b OR g<eta<h AND c<eta<d if e<eta<f
        % This may result in at most two distinct intervals, and function returns (lower bound1, upper bound1, lower bound2, upper bound2).
        temp=zeros(1,4); %temporary variable
        temp(1,:)=kinksegment(theta11(i,1),theta12(i,1),ua13(i,1),uf13(i,1),theta23(i,1),theta33(i,1),0,0); %start from theta11<eta<theta12 and (ua13<eta<uf13 if theta23<eta<theta33)
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua14(i,1),uf14(i,1),theta34(i,1),theta44(i,1),temp(1,3),temp(1,4)); % use bounds from previous iteration as the starting point: (a,b) and (g,h)
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua15(i,1),uf15(i,1),theta45(i,1),theta55(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua16(i,1),uf16(i,1),theta56(i,1),theta66(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua17(i,1),uf17(i,1),theta67(i,1),theta77(i,1),temp(1,3),temp(1,4));
        
        lo1k(i)=max([-big,temp(1,1)],[],2); % keeps every bound between -big and +big
        up1k(i)=min([big,max(-big,temp(1,2))],[],2);
        lo1ka(i)=max([-big,temp(1,3)],[],2);
        up1ka(i)=min([big,max(-big,temp(1,4))],[],2);
        
        %2 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta12(i,1),theta22(i,1),max(eta23(i,1),theta23(i,1)),theta33(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta24(i,1),theta34(i,1)),theta44(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta25(i,1),theta45(i,1)),theta55(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta26(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta27(i,1),theta67(i,1)),theta77(i,1));
        
        lo2s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2); %note the inclusion of theta11: if s1 is feasible, it is also optimal. We do not want this bound to apply when lowerbound=upperbound=0.
        up2s(i)=min([big,max(-big,temp(1,2))],[],2);
        lo2sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up2sa(i)=min([big,max(-big,temp(1,4))],[],2);
        
        %3 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta23(i,1),theta33(i,1),max(eta34(i,1),theta34(i,1)),theta44(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta35(i,1),theta45(i,1)),theta55(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta36(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta37(i,1),theta67(i,1)),theta77(i,1));
        %compare with lower segments
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta23(i,1),theta22(i,1)));
        %1 kink point comparison
        temp(1,:)=segmentkink(ua13(i,1),uf13(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo3s(i)=max([-big,theta11(i,1).*(temp(1,1)~=0),temp(1,1)],[],2);
        up3s(i)=min([big,max(-big,temp(1,2))],[],2);
        lo3sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up3sa(i)=min([big,max(-big,temp(1,4))],[],2);
        
        %4 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta34(i,1),theta44(i,1),max(eta45(i,1),theta45(i,1)),theta55(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta46(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta47(i,1),theta67(i,1)),theta77(i,1));
        %compare with lower segments
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta24(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta34(i,1),theta33(i,1)));
        %1 kink point comparison
        temp(1,:)=segmentkink(ua14(i,1),uf14(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo4s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up4s(i)=min([big,max(-big,temp(1,2))],[],2);
        lo4sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up4sa(i)=min([big,max(-big,temp(1,4))],[],2);
        
        %5 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta45(i,1),theta55(i,1),max(eta56(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta57(i,1),theta67(i,1)),theta77(i,1));
        %compare with lower segments
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta25(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta35(i,1),theta33(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta34(i,1),min(eta45(i,1),theta44(i,1)));
        %1 kink point comparison
        temp(1,:)=segmentkink(ua15(i,1),uf15(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo5s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up5s(i)=min([big,max(-big,temp(1,2))],[],2);
        lo5sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up5sa(i)=min([big,max(-big,temp(1,4))],[],2);
        
        %6 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta56(i,1),theta66(i,1),max(eta67(i,1),theta67(i,1)),theta77(i,1));
        %compare with lower segments
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta26(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta36(i,1),theta33(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta34(i,1),min(eta46(i,1),theta44(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta45(i,1),min(eta56(i,1),theta55(i,1)));
        %1 kink point comparison
        temp(1,:)=segmentkink(ua16(i,1),uf16(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo6s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up6s(i)=min([big,max(-big,temp(1,2))],[],2);
        lo6sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up6sa(i)=min([big,max(-big,temp(1,4))],[],2);
        
        %7 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta67(i,1),theta77(i,1),theta12(i,1),min(eta27(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta37(i,1),theta33(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta34(i,1),min(eta47(i,1),theta44(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta45(i,1),min(eta57(i,1),theta55(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta56(i,1),min(eta67(i,1),theta66(i,1)));
        %1 kink point comparison
        temp(1,:)=segmentkink(ua17(i,1),uf17(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo7s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up7s(i)=min([big,max(-big,temp(1,2))],[],2);
        lo7sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up7sa(i)=min([big,max(-big,temp(1,4))],[],2);
        
        
        %TYEAR 4 AND RICH=1
        %%%%%%%%%%%%%%%%%%%%%%%
        
    elseif tyear(i,1)==4 && rich(i,1)==1
        
        %1 kink point
        temp=zeros(1,4);
        temp(1,:)=kinksegment(theta11(i,1),theta12(i,1),ua13(i,1),uf13(i,1),theta23(i,1),theta33(i,1),0,0);
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua14(i,1),uf14(i,1),theta34(i,1),theta44(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua15(i,1),uf15(i,1),theta45(i,1),theta55(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua16(i,1),uf16(i,1),theta56(i,1),theta66(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua17(i,1),uf17(i,1),theta67(i,1),theta77(i,1),temp(1,3),temp(1,4));
        %compare to kink point
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(uu17(i,1),theta77(i,1)),theta78(i,1));
        
        lo1k(i)=max([-big,temp(1,1)],[],2);
        up1k(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo1ka(i)=max([-big,temp(1,3)],[],2);
        up1ka(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %2 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta12(i,1),theta22(i,1),max(eta23(i,1),theta23(i,1)),theta33(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta24(i,1),theta34(i,1)),theta44(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta25(i,1),theta45(i,1)),theta55(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta26(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta27(i,1),theta67(i,1)),theta77(i,1));
        
        temp(1,:)=segmentkink(ua13(i,1),uf13(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua73(i,1),uf73(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo2s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up2s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo2sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up2sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %3 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta23(i,1),theta33(i,1),max(eta34(i,1),theta34(i,1)),theta44(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta35(i,1),theta45(i,1)),theta55(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta36(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta37(i,1),theta67(i,1)),theta77(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta23(i,1),theta22(i,1)));
        
        temp(1,:)=segmentkink(ua13(i,1),uf13(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua73(i,1),uf73(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo3s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up3s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo3sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up3sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %4 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta34(i,1),theta44(i,1),max(eta45(i,1),theta45(i,1)),theta55(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta46(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta47(i,1),theta67(i,1)),theta77(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta24(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta34(i,1),theta33(i,1)));
        
        temp(1,:)=segmentkink(ua14(i,1),uf14(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua74(i,1),uf74(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo4s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up4s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo4sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up4sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %5 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta45(i,1),theta55(i,1),max(eta56(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta57(i,1),theta67(i,1)),theta77(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta25(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta35(i,1),theta33(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta34(i,1),min(eta45(i,1),theta44(i,1)));
        
        temp(1,:)=segmentkink(ua15(i,1),uf15(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua75(i,1),uf75(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo5s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up5s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo5sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up5sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %6 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta56(i,1),theta66(i,1),max(eta67(i,1),theta67(i,1)),theta77(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta26(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta36(i,1),theta33(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta34(i,1),min(eta46(i,1),theta44(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta45(i,1),min(eta56(i,1),theta55(i,1)));
        
        temp(1,:)=segmentkink(ua16(i,1),uf16(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua76(i,1),uf76(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo6s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up6s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo6sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up6sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %7 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta67(i,1),theta77(i,1),theta12(i,1),min(eta27(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta37(i,1),theta33(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta34(i,1),min(eta47(i,1),theta44(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta45(i,1),min(eta57(i,1),theta55(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta56(i,1),min(eta67(i,1),theta66(i,1)));
        
        temp(1,:)=segmentkink(ua17(i,1),uf17(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo7s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up7s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo7sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up7sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %7 kink point
        temp=zeros(1,4);
        temp(1,:)=kinksegment(theta77(i,1),theta78(i,1),ua73(i,1),uf73(i,1),theta23(i,1),theta33(i,1),0,0);
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua74(i,1),uf74(i,1),theta34(i,1),theta44(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua75(i,1),uf75(i,1),theta45(i,1),theta55(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua76(i,1),uf76(i,1),theta56(i,1),theta66(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua72(i,1),uf72(i,1),theta12(i,1),theta22(i,1),temp(1,3),temp(1,4));
        
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta11(i,1),min(uu17(i,1),theta12(i,1)));
        
        lo7k(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up7k(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo7ka(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up7ka(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %8 segment
        lo8s(i)=max([-big,theta78(i,1)],[],2);
        
        
        %TYEAR 5,6
        %%%%%%%%%%%%%%
        
    elseif (tyear(i,1)==5 || tyear(i,1)==6) && rich(i)==1
        
        %1 kink point
        temp=zeros(1,4);
        temp(1,:)=kinksegment(theta11(i,1),theta12(i,1),ua13(i,1),uf13(i,1),theta23(i,1),theta33(i,1),0,0);
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua14(i,1),uf14(i,1),theta34(i,1),theta44(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua15(i,1),uf15(i,1),theta45(i,1),theta55(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua16(i,1),uf16(i,1),theta56(i,1),theta66(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua17(i,1),uf17(i,1),theta67(i,1),theta77(i,1),temp(1,3),temp(1,4));
        
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(uu16(i,1),theta66(i,1)),theta67(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(uu17(i,1),theta77(i,1)),theta78(i,1));
        
        lo1k(i)=max([-big,temp(1,1)],[],2);
        up1k(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo1ka(i)=max([-big,temp(1,3)],[],2);
        up1ka(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %2 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta12(i,1),theta22(i,1),max(eta23(i,1),theta23(i,1)),theta33(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta24(i,1),theta34(i,1)),theta44(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta25(i,1),theta45(i,1)),theta55(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta26(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta27(i,1),theta67(i,1)),theta77(i,1));
        
        temp(1,:)=segmentkink(ua62(i,1),uf62(i,1),theta66(i,1),theta67(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua72(i,1),uf72(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo2s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up2s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo2sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up2sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %3 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta23(i,1),theta33(i,1),max(eta34(i,1),theta34(i,1)),theta44(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta35(i,1),theta45(i,1)),theta55(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta36(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta37(i,1),theta67(i,1)),theta77(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta23(i,1),theta22(i,1)));
        
        temp(1,:)=segmentkink(ua13(i,1),uf13(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua63(i,1),uf63(i,1),theta66(i,1),theta67(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua73(i,1),uf73(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo3s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up3s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo3sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up3sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %4 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta34(i,1),theta44(i,1),max(eta45(i,1),theta45(i,1)),theta55(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta46(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta47(i,1),theta67(i,1)),theta77(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta24(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta34(i,1),theta33(i,1)));
        
        temp(1,:)=segmentkink(ua14(i,1),uf14(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua64(i,1),uf64(i,1),theta66(i,1),theta67(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua74(i,1),uf74(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo4s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up4s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo4sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up4sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %5 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta45(i,1),theta55(i,1),max(eta56(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta57(i,1),theta67(i,1)),theta77(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta12(i,1),min(eta25(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta35(i,1),theta33(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta34(i,1),min(eta45(i,1),theta44(i,1)));
        
        temp(1,:)=segmentkink(ua15(i,1),uf15(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua65(i,1),uf65(i,1),theta66(i,1),theta67(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua75(i,1),uf75(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo5s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up5s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo5sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up5sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %6 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta56(i,1),theta66(i,1),theta12(i,1),min(eta26(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta36(i,1),theta33(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta34(i,1),min(eta46(i,1),theta44(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta45(i,1),min(eta56(i,1),theta55(i,1)));
        
        temp(1,:)=segmentkink(ua16(i,1),uf16(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo6s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up6s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo6sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up6sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %6 kink point
        temp=zeros(1,4);
        temp(1,:)=kinksegment(theta66(i,1),theta67(i,1),ua63(i,1),uf63(i,1),theta23(i,1),theta33(i,1),0,0);
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua64(i,1),uf64(i,1),theta34(i,1),theta44(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua65(i,1),uf65(i,1),theta45(i,1),theta55(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua62(i,1),uf62(i,1),theta12(i,1),theta22(i,1),temp(1,3),temp(1,4));
        
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta11(i,1),min(uu16(i,1),theta12(i,1)));
        
        lo6k(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up6k(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo6ka(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up6ka(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %7 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(max(theta67(i,1),theta66(i,1)),theta77(i,1),theta12(i,1),min(eta27(i,1),theta22(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta23(i,1),min(eta37(i,1),theta33(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta34(i,1),min(eta47(i,1),theta44(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta45(i,1),min(eta57(i,1),theta55(i,1)));
        
        temp(1,:)=segmentkink(ua17(i,1),uf17(i,1),theta11(i,1),theta12(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo7s(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up7s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo7sa(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up7sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %7 kink point
        temp=zeros(1,4);
        temp(1,:)=kinksegment(max([theta66(i,1),theta67(i,1),theta77(i,1)],[],2),theta78(i,1),ua73(i,1),uf73(i,1),theta23(i,1),theta33(i,1),0,0);
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua74(i,1),uf74(i,1),theta34(i,1),theta44(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua75(i,1),uf75(i,1),theta45(i,1),theta55(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua72(i,1),uf72(i,1),theta12(i,1),theta22(i,1),temp(1,3),temp(1,4));
        
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta11(i,1),min(uu17(i,1),theta12(i,1)));
        
        lo7k(i)=max([-big,theta11(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up7k(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo7ka(i)=max([-big,theta11(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up7ka(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %8 segment
        lo8s(i)=max([-big,theta78(i,1)],[],2);
        
        %TYEAR 7,8 & RICH=1
        %%%%%%%%%%%%%%%%%%%%%
        
    elseif (tyear(i,1)==7 || tyear(i,1)==8) && rich(i)==1
        
        %1 kink point
        lo1k(i)=max(-big,theta11(i,1));
        up1k(i)=min(big,theta12(i,1));
        
        %2 segment
        lo2s(i)=max(-big,theta12(i,1));
        up2s(i)=min(big,theta22(i,1));
        
        %2 kink point
        lo2k(i)=max(-big,theta22(i,1));
        up2k(i)=min(big,theta23(i,1));
        
        %3 segment
        lo3s(i)=max(-big,theta23(i,1));
        up3s(i)=min(big,theta33(i,1));
        
        %3 kink point
        temp=zeros(1,4);
        temp(1,:)=compare1(theta33(i,1),theta34(i,1),max(uu36(i,1),theta66(i,1)),theta67(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(uu37(i,1),theta77(i,1)),theta78(i,1));
        
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua36(i,1),uf36(i,1),theta56(i,1),theta66(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua37(i,1),uf37(i,1),theta67(i,1),theta77(i,1),temp(1,3),temp(1,4));
        
        lo3k(i)=max([-big,temp(1,1)],[],2);
        up3k(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo3ka(i)=max([-big,temp(1,3)],[],2);
        up3ka(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %4 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta34(i,1),theta44(i,1),max(eta46(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta47(i,1),theta67(i,1)),theta77(i,1));
        
        temp(1,:)=segmentkink(ua64(i,1),uf64(i,1),theta66(i,1),theta67(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua74(i,1),uf74(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo4s(i)=max([-big,theta33(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up4s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo4sa(i)=max([-big,theta33(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up4sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %4 kink point
        temp=zeros(1,4);
        temp(1,:)=compare1(theta44(i,1),theta45(i,1),max(uu46(i,1),theta66(i,1)),theta67(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(uu47(i,1),theta77(i,1)),theta78(i,1));
        
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua46(i,1),uf46(i,1),theta56(i,1),theta66(i,1),temp(1,3),temp(1,4));
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua47(i,1),uf47(i,1),theta67(i,1),theta77(i,1),temp(1,3),temp(1,4));
        
        lo4k(i)=max([-big,theta33(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up4k(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo4ka(i)=max([-big,theta33(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up4ka(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %5 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta45(i,1),theta55(i,1),max(eta56(i,1),theta56(i,1)),theta66(i,1));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),max(eta57(i,1),theta67(i,1)),theta77(i,1));
        
        temp(1,:)=segmentkink(ua65(i,1),uf65(i,1),theta66(i,1),theta67(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua75(i,1),uf75(i,1),theta77(i,1),theta78(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo5s(i)=max([-big,theta33(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up5s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo5sa(i)=max([-big,theta33(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up5sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %6 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta56(i,1),theta66(i,1),theta34(i,1),min(eta46(i,1),theta44(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta45(i,1),min(eta56(i,1),theta55(i,1)));
        
        temp(1,:)=segmentkink(ua36(i,1),uf36(i,1),theta33(i,1),theta34(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua46(i,1),uf46(i,1),theta44(i,1),theta45(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo6s(i)=max([-big,theta33(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up6s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo6sa(i)=max([-big,theta33(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up6sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %6 kink point
        temp=zeros(1,4);
        temp(1,:)=kinksegment(theta66(i,1),theta67(i,1),ua64(i,1),uf64(i,1),theta34(i,1),theta44(i,1),0,0);
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua65(i,1),uf65(i,1),theta45(i,1),theta55(i,1),temp(1,3),temp(1,4));
        
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta44(i,1),min(uu46(i,1),theta45(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta33(i,1),min(uu36(i,1),theta34(i,1)));
        
        lo6k(i)=max([-big,theta33(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up6k(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo6ka(i)=max([-big,theta33(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up6ka(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %7 segment
        temp=zeros(1,4);
        temp(1,:)=compare1(theta67(i,1),theta77(i,1),theta34(i,1),min(eta47(i,1),theta44(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta45(i,1),min(eta57(i,1),theta55(i,1)));
        
        temp(1,:)=segmentkink(ua37(i,1),uf37(i,1),theta33(i,1),theta34(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        temp(1,:)=segmentkink(ua47(i,1),uf47(i,1),theta44(i,1),theta45(i,1),temp(1,1),temp(1,2),temp(1,3),temp(1,4));
        
        lo7s(i)=max([-big,theta33(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up7s(i)=min([big,theta78(i,1)*(temp(1,2)~=0),temp(1,2)],[],2);
        lo7sa(i)=max([-big,theta33(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up7sa(i)=min([big,theta78(i,1)*(temp(1,4)~=0),temp(1,4)],[],2);
        
        %7 kink point
        temp=zeros(1,4);
        temp(1,:)=kinksegment(theta77(i,1),theta78(i,1),ua74(i,1),uf74(i,1),theta34(i,1),theta44(i,1),0,0);
        temp(1,:)=kinksegment(temp(1,1),temp(1,2),ua75(i,1),uf75(i,1),theta45(i,1),theta55(i,1),temp(1,3),temp(1,4));
        
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta33(i,1),min(uu37(i,1),theta34(i,1)));
        temp(1,:)=compare2(temp(1,1),temp(1,2),temp(1,3),temp(1,4),theta44(i,1),min(uu47(i,1),theta45(i,1)));
        
        lo7k(i)=max([-big,theta33(i,1)*(temp(1,1)~=0),temp(1,1)],[],2);
        up7k(i)=min([big,max(-big,temp(1,2))],[],2);
        lo7ka(i)=max([-big,theta33(i,1)*(temp(1,3)~=0),temp(1,3)],[],2);
        up7ka(i)=min([big,max(-big,temp(1,4))],[],2);
        
        %8 segment
        lo8s(i)=max(-big,theta78(i,1));

        
        % RICH=0
        %%%%%%%%%%%
        
    elseif rich(i)==0
        
        up1s(i)=theta11(i);
        lo1k(i)=theta11(i);
        up1k(i)=theta12(i);
        lo2s(i)=theta12(i);
        up2s(i)=theta22(i);
        lo2k(i)=theta22(i);
        up2k(i)=theta23(i);
        lo3s(i)=theta23(i);
        up3s(i)=theta33(i);
        lo3k(i)=theta33(i);
        up3k(i)=theta34(i);
        lo4s(i)=theta34(i);
        up4s(i)=theta44(i);
        lo4k(i)=theta44(i);
        up4k(i)=theta45(i);
        lo5s(i)=theta45(i);
        up5s(i)=theta55(i);
        lo5k(i)=theta55(i);
        up5k(i)=theta56(i);
        lo6s(i)=theta56(i);
        up6s(i)=theta66(i);
        lo6k(i)=theta66(i);
        up6k(i)=theta67(i);
        lo7s(i)=theta67(i);
        up7s(i)=theta77(i);
        lo7k(i)=theta77(i);
        up7k(i)=theta78(i);
        lo8s(i)=theta78(i);
        
    end
end

%check bounds
bounds=[up1s lo1k up1k lo2s up2s lo2k up2k lo3s up3s lo3k up3k lo4s up4s lo4k up4k lo5s up5s lo5k up5k lo6s up6s lo6k up6k lo7s up7s lo7k up7k lo8s];

    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       SETTING UP THE TERMS IN THE LIKELIHOOD
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% see eqn (22) in the paper

s1=(y-wstar1)/sv;
s2=(y-wstar2)/sv;
s3=(y-wstar3)/sv;
s4=(y-wstar4)/sv;
s5=(y-wstar5)/sv;
s6=(y-wstar6)/sv;
s7=(y-wstar7)/sv;
s8=(y-wstar8)/sv;

u1=(y-w(:,1))/s0;
u2=(y-w(:,2))/s0;
u3=(y-w(:,3))/s0;
u4=(y-w(:,4))/s0;
u5=(y-w(:,5))/s0;
u6=(y-w(:,6))/s0;
u7=(y-w(:,7))/s0;

%truncation
wstar=[wstar1 wstar2 wstar3 wstar4 wstar5 wstar6 wstar7 wstar8];
trunc=nanmin(-wstar,[],2)-bp/by; % eta upper bar
tr2=normcdf(trunc/sn,0,1)+0.0000000001; %add small number to avoid dividing by zero below


argup1s=(min([trunc,up1s],[],2)/sn-corr*s1)/sqrt(1-(corr^2)); % these will be the arguments of the st.normal distribution
arglo2s=(min([trunc,lo2s],[],2)/sn-corr*s2)/sqrt(1-(corr^2));
argup2s=(min([trunc,up2s],[],2)/sn-corr*s2)/sqrt(1-(corr^2));
arglo3s=(min([trunc,lo3s],[],2)/sn-corr*s3)/sqrt(1-(corr^2));
argup3s=(min([trunc,up3s],[],2)/sn-corr*s3)/sqrt(1-(corr^2));
arglo4s=(min([trunc,lo4s],[],2)/sn-corr*s4)/sqrt(1-(corr^2));
argup4s=(min([trunc,up4s],[],2)/sn-corr*s4)/sqrt(1-(corr^2));
arglo5s=(min([trunc,lo5s],[],2)/sn-corr*s5)/sqrt(1-(corr^2));
argup5s=(min([trunc,up5s],[],2)/sn-corr*s5)/sqrt(1-(corr^2));
arglo6s=(min([trunc,lo6s],[],2)/sn-corr*s6)/sqrt(1-(corr^2));
argup6s=(min([trunc,up6s],[],2)/sn-corr*s6)/sqrt(1-(corr^2));
arglo7s=(min([trunc,lo7s],[],2)/sn-corr*s7)/sqrt(1-(corr^2));
argup7s=(min([trunc,up7s],[],2)/sn-corr*s7)/sqrt(1-(corr^2));
arglo8s=(min([trunc,lo8s],[],2)/sn-corr*s8)/sqrt(1-(corr^2));
argup8s=(trunc/sn-corr*s8)/sqrt(1-(corr^2));

arglo1k=min([trunc,lo1k],[],2)/s0;
argup1k=min([trunc,up1k],[],2)/s0;
arglo2k=min([trunc,lo2k],[],2)/s0;
argup2k=min([trunc,up2k],[],2)/s0;
arglo3k=min([trunc,lo3k],[],2)/s0;
argup3k=min([trunc,up3k],[],2)/s0;
arglo4k=min([trunc,lo4k],[],2)/s0;
argup4k=min([trunc,up4k],[],2)/s0;
arglo5k=min([trunc,lo5k],[],2)/s0;
argup5k=min([trunc,up5k],[],2)/s0;
arglo6k=min([trunc,lo6k],[],2)/s0;
argup6k=min([trunc,up6k],[],2)/s0;
arglo7k=min([trunc,lo7k],[],2)/s0;
argup7k=min([trunc,up7k],[],2)/s0;

arglo2sa=(min([trunc,lo2sa],[],2)/sn-corr*s2)/sqrt(1-(corr^2));
argup2sa=(min([trunc,up2sa],[],2)/sn-corr*s2)/sqrt(1-(corr^2));
arglo3sa=(min([trunc,lo3sa],[],2)/sn-corr*s3)/sqrt(1-(corr^2));
argup3sa=(min([trunc,up3sa],[],2)/sn-corr*s3)/sqrt(1-(corr^2));
arglo4sa=(min([trunc,lo4sa],[],2)/sn-corr*s4)/sqrt(1-(corr^2));
argup4sa=(min([trunc,up4sa],[],2)/sn-corr*s4)/sqrt(1-(corr^2));
arglo5sa=(min([trunc,lo5sa],[],2)/sn-corr*s5)/sqrt(1-(corr^2));
argup5sa=(min([trunc,up5sa],[],2)/sn-corr*s5)/sqrt(1-(corr^2));
arglo6sa=(min([trunc,lo6sa],[],2)/sn-corr*s6)/sqrt(1-(corr^2));
argup6sa=(min([trunc,up6sa],[],2)/sn-corr*s6)/sqrt(1-(corr^2));
arglo7sa=(min([trunc,lo7sa],[],2)/sn-corr*s7)/sqrt(1-(corr^2));
argup7sa=(min([trunc,up7sa],[],2)/sn-corr*s7)/sqrt(1-(corr^2));

arglo1ka=min([trunc,lo1ka],[],2)/s0;
argup1ka=min([trunc,up1ka],[],2)/s0;
arglo2ka=min([trunc,lo2ka],[],2)/s0;
argup2ka=min([trunc,up2ka],[],2)/s0;
arglo3ka=min([trunc,lo3ka],[],2)/s0;
argup3ka=min([trunc,up3ka],[],2)/s0;
arglo4ka=min([trunc,lo4ka],[],2)/s0;
argup4ka=min([trunc,up4ka],[],2)/s0;
arglo6ka=min([trunc,lo6ka],[],2)/s0;
argup6ka=min([trunc,up6ka],[],2)/s0;
arglo7ka=min([trunc,lo7ka],[],2)/s0;
argup7ka=min([trunc,up7ka],[],2)/s0;

% putting together the Likelihood: L1-L8 are the terms for the segments, Lk1-Lk7 are the terms for the kinks
% L1a, L2a etc. are for the second set of bounds, if any

L1=zeros(n,1);
L2=zeros(n,1);
L3=zeros(n,1);
L4=zeros(n,1);
L5=zeros(n,1);
L6=zeros(n,1);
L7=zeros(n,1);
L8=zeros(n,1);
Lk1=zeros(n,1);
Lk2=zeros(n,1);
Lk3=zeros(n,1);
Lk4=zeros(n,1);
Lk5=zeros(n,1);
Lk6=zeros(n,1);
Lk7=zeros(n,1);

L2a=zeros(n,1);
L3a=zeros(n,1);
L4a=zeros(n,1);
L5a=zeros(n,1);
L6a=zeros(n,1);
L7a=zeros(n,1);
L8a=zeros(n,1);
Lk1a=zeros(n,1);
Lk2a=zeros(n,1);
Lk3a=zeros(n,1);
Lk4a=zeros(n,1);
Lk5a=zeros(n,1);
Lk6a=zeros(n,1);
Lk7a=zeros(n,1);

for i=1:n
    L1(i,1)=exp(-s1(i,1)*s1(i,1)/2)/sv*normcdf(argup1s(i,1))/tr2(i,1)/sn;
    L2(i,1)=exp(-s2(i,1)*s2(i,1)/2)/sv*(max(0,(normcdf(argup2s(i,1))-normcdf(arglo2s(i,1)))))/tr2(i,1);
    L3(i,1)=exp(-s3(i,1)*s3(i,1)/2)/sv*(max(0,(normcdf(argup3s(i,1))-normcdf(arglo3s(i,1)))))/tr2(i,1);
    L4(i,1)=exp(-s4(i,1)*s4(i,1)/2)/sv*(max(0,(normcdf(argup4s(i,1))-normcdf(arglo4s(i,1)))))/tr2(i,1);
    L5(i,1)=exp(-s5(i,1)*s5(i,1)/2)/sv*(max(0,(normcdf(argup5s(i,1))-normcdf(arglo5s(i,1)))))/tr2(i,1);
    L6(i,1)=exp(-s6(i,1)*s6(i,1)/2)/sv*(max(0,(normcdf(argup6s(i,1))-normcdf(arglo6s(i,1)))))/tr2(i,1);
    if rich(i)==0 && (tyear(i)==5 || tyear(i)==6)
        L7(i,1)=0;
    else
        L7(i,1)=exp(-s7(i,1)*s7(i,1)/2)/sv*(max(0,(normcdf(argup7s(i,1))-normcdf(arglo7s(i,1)))))/tr2(i,1);
    end
    if tyear(i)<=3 || (rich(i)==0 && (tyear(i)==5 || tyear(i)==6)) || (rich(i)==0 && (tyear(i)==7 || tyear(i)==8))
        L8(i,1)=0;
    else
        L8(i,1)=exp(-s8(i,1)*s8(i,1)/2)/sv*(max(0,(normcdf(argup8s(i,1))-normcdf(arglo8s(i,1)))))/tr2(i,1);
    end
    
    Lk1(i,1)=exp(-u1(i,1)*u1(i,1)/2)/s0*(max(0,(normcdf(argup1k(i,1))-normcdf(arglo1k(i,1)))))/tr2(i,1);
    Lk2(i,1)=exp(-u2(i,1)*u2(i,1)/2)/s0*(max(0,(normcdf(argup2k(i,1))-normcdf(arglo2k(i,1)))))/tr2(i,1);
    Lk3(i,1)=exp(-u3(i,1)*u3(i,1)/2)/s0*(max(0,(normcdf(argup3k(i,1))-normcdf(arglo3k(i,1)))))/tr2(i,1);
    Lk4(i,1)=exp(-u4(i,1)*u4(i,1)/2)/s0*(max(0,(normcdf(argup4k(i,1))-normcdf(arglo4k(i,1)))))/tr2(i,1);
    Lk5(i,1)=exp(-u5(i,1)*u5(i,1)/2)/s0*(max(0,(normcdf(argup5k(i,1))-normcdf(arglo5k(i,1)))))/tr2(i,1);
    if rich(i)==0 && (tyear(i)==5 || tyear(i)==6)
        Lk6(i,1)=0;
    else
        Lk6(i,1)=exp(-u6(i,1)*u6(i,1)/2)/s0*(max(0,(normcdf(argup6k(i,1))-normcdf(arglo6k(i,1)))))/tr2(i,1);
    end
    if tyear(i)<=3 || (rich(i)==0 && (tyear(i)==5 || tyear(i)==6)) || (rich(i)==0 && (tyear(i)==7 || tyear(i)==8))
        Lk7(i,1)=0;
    else
        Lk7(i,1)=exp(-u7(i,1)*u7(i,1)/2)/s0*(max(0,(normcdf(argup7k(i,1))-normcdf(arglo7k(i,1)))))/tr2(i,1);
    end
    
    L2a(i,1)=exp(-s2(i,1)*s2(i,1)/2)/sv*(max(0,(normcdf(argup2sa(i,1))-normcdf(arglo2sa(i,1)))))/tr2(i,1);
    L3a(i,1)=exp(-s3(i,1)*s3(i,1)/2)/sv*(max(0,(normcdf(argup3sa(i,1))-normcdf(arglo3sa(i,1)))))/tr2(i,1);
    L4a(i,1)=exp(-s4(i,1)*s4(i,1)/2)/sv*(max(0,(normcdf(argup4sa(i,1))-normcdf(arglo4sa(i,1)))))/tr2(i,1);
    L5a(i,1)=exp(-s5(i,1)*s5(i,1)/2)/sv*(max(0,(normcdf(argup5sa(i,1))-normcdf(arglo5sa(i,1)))))/tr2(i,1);
    L6a(i,1)=exp(-s6(i,1)*s6(i,1)/2)/sv*(max(0,(normcdf(argup6sa(i,1))-normcdf(arglo6sa(i,1)))))/tr2(i,1);
    if rich(i)==0 && (tyear(i)==5 || tyear(i)==6)
        L7a(i,1)=0;
    else
        L7a(i,1)=exp(-s7(i,1)*s7(i,1)/2)/sv*(max(0,(normcdf(argup7sa(i,1))-normcdf(arglo7sa(i,1)))))/tr2(i,1);
    end
    
    Lk1a(i,1)=exp(-u1(i,1)*u1(i,1)/2)/s0*(max(0,(normcdf(argup1ka(i,1))-normcdf(arglo1ka(i,1)))))/tr2(i,1);
    Lk2a(i,1)=exp(-u2(i,1)*u2(i,1)/2)/s0*(max(0,(normcdf(argup2ka(i,1))-normcdf(arglo2ka(i,1)))))/tr2(i,1);
    Lk3a(i,1)=exp(-u3(i,1)*u3(i,1)/2)/s0*(max(0,(normcdf(argup3ka(i,1))-normcdf(arglo3ka(i,1)))))/tr2(i,1);
    Lk4a(i,1)=exp(-u4(i,1)*u4(i,1)/2)/s0*(max(0,(normcdf(argup4ka(i,1))-normcdf(arglo4ka(i,1)))))/tr2(i,1);
    if rich(i)==0 && (tyear(i)==5 || tyear(i)==6)
        Lk6a(i,1)=0;
    else
        Lk6a(i,1)=exp(-u6(i,1)*u6(i,1)/2)/s0*(max(0,(normcdf(argup6ka(i,1))-normcdf(arglo6ka(i,1)))))/tr2(i,1);
    end
    if tyear(i)<=3 || (rich(i)==0 && (tyear(i)==5 || tyear(i)==6)) || (rich(i)==0 && (tyear(i)==7 || tyear(i)==8))
        Lk7a(i,1)=0;
    else
        Lk7a(i,1)=exp(-u7(i,1)*u7(i,1)/2)/s0*(max(0,(normcdf(argup7ka(i,1))-normcdf(arglo7ka(i,1)))))/tr2(i,1);
    end
end

L=(L1+L2+L3+L4+L5+L6+L7+L8+Lk1+Lk2+Lk3+Lk4+Lk5+Lk6+Lk7+L2a+L3a+L4a+L5a+L6a+L7a+L8a+Lk1a+Lk2a+Lk3a+Lk4a+Lk5a+Lk6a+Lk7a+0.00001);

Lcheck=[L1 Lk1 L2 Lk2 L3 Lk3 L4 Lk4 L5 Lk5 L6 Lk6 L7 Lk7 L8 L2a L3a L4a L5a L6a L7a L8a Lk1a Lk2a Lk3a Lk4a Lk5a Lk6a Lk7a];


val=-sum(log(L));
display(val);

llf=-sum(log(L)); %sample LLHF
 