
%read the data
[data] = textread('data.csv','','delimiter',',','emptyvalue',NaN);

%column 1 is the identifier, subsequent columns described below:
tyear=data(:,2); %tariff year
y=data(:,3); %observed consumption
n=length(y);
X=[ones(n,1) data(:,4:12)]; %explanatory variables: indigent, restricted, sanitation, temperature, washing machine, #people on property, outdoor water usage, bathtub or shower, completed high school
ind=data(:,4);  %1 if indigent
rest=data(:,5); %1 if restricted
rich=data(:,6); %1 if has sanitation
p=data(:,13:20); %marginal prices in the tariff schedule
inc=data(:,21:28);  %virtual income
w=data(:,29:35); %kink points in the tariff schedule
k=size(X,2);

load startingvalues.txt; %starting values for the parameters, ordered as follows: X, price, income, sqrt(sigma_eta), sqrt(sigma_epsilon)

%for estimation, first run fminsearch, then use fminunc to refine the estimates
[x,fval,exitflag,output]=fminsearch(@likelihood,x0,options,y,X,n,k,w,p,inc,tyear,ind,rich);     

x0=x;
[x,fval,exitflag,output]=fminunc(@likelihood,x0,options,y,X,n,k,w,p,inc,tyear,ind,rich);


%compute standard errors as described at the end of Section 5.2 in the paper
%estimating the Hessian matrix
step=1e-3*abs(x);

Hessian=zeros(14,14);
for i=1:14
for j=i:14
    hi=step(i);
    hj=step(j);
    deltai=zeros(1,14);
    deltai(i)=hi;
    deltaj=zeros(1,14);
    deltaj(j)=hj;
    logplus1=zeros(n,1);
    logminus1=zeros(n,1);
    [logplus1]=standarderrors(x+deltai'+deltaj',y,X,n,k,w,p,inc,tyear,ind,rich);
    [logminus1]=standarderrors(x-deltai'+deltaj',y,X,n,k,w,p,inc,tyear,ind,rich);
    [logplus2]=standarderrors(x+deltai'-deltaj',y,X,n,k,w,p,inc,tyear,ind,rich);
    [logminus2]=standarderrors(x-deltai'-deltaj',y,X,n,k,w,p,inc,tyear,ind,rich);
    logplus1s=sum(logplus1);
    logminus1s=sum(logminus1);
    logplus2s=sum(logplus2);
    logminus2s=sum(logminus2); 
    Hessian(i,j)=-((logplus1s-logminus1s)/(2*hi)-(logplus2s-logminus2s)/(2*hi))/(2*hj);
    Hessian(j,i)=-((logplus1s-logminus1s)/(2*hi)-(logplus2s-logminus2s)/(2*hi))/(2*hj);
end   
end

H1=inv(Hessian);                  

scores=zeros(n,14);
for i=1:14
    h=step(i);
    delta=zeros(1,14);
    logplus=zeros(n,1);
    logminus=zeros(n,1);
    delta(i)=h;
    [logplus]=standarderrors(x+delta',y,X,n,k,w,p,inc,tyear,ind,rich);
    [logminus]=standarderrors(x-delta',y,X,n,k,w,p,inc,tyear,ind,rich);
    scores(:,i)=(logplus-logminus)/(2*h);
end

accno=data(:,1);
for i=1:14
[newscores(:,i) id(:,i)]=grpstats(scores(:,i),accno,{'sum','gname'})
end

I1new=newscores'*newscores;
Snew=H1*(I1new)*H1;
S2new=diag(Snew);
se2new=sqrt(S2new); 
 
se_s21new=sqrt((2*x(end-1))^2*S2new(end -1)); 
se_s22new=sqrt((2*x(end))^2*S2new(end));

%the code above produces the values in the first two columns of Table 9
%("Maximum Likelihood parameter estimates and marginal effects" in the paper)